"FILE"="Xteq Systems X-Setup Plugin 6.0"
"TYPE"="8"
"COUNT"="3"
"UIPATH"="Network\DHCP"
"NAME"="DHCP Plus Secondary IP Address"
"VERSION"="1.12"
"LANGUAGE"="VBScript"
"OSVERSION"="0001011"
"WARNING"="1"
"TEXT 1"="Show GUID"
"TEXT 2"="Add/Edit"
"TEXT 3"="Remove"
"DESCRIPTION 1"="These days, most networks assign IP Number by using a DHCP server. By default, Windows does only allow to either use a DHCP assigned IP address, or a static (user-configured) IP address - not both at the same time. In some conditions however, you might want to have one more address beside the DHCP assigned IP address. With this setting, you can do just that."
"DESCRIPTION 2"="Simply click on the network connection where you would like to have an additional IP address and click on the "Add/Edit". Please note that this IP address will share the same settings (DNS Servers, WINS Servers etc.) as the DHCP assigned IP address. "
"DESCRIPTION 3"="When you are done with this, simply start and stop (Enable/Disable) the changed network connection by using Start -> Control Panel -> Network Connections. Once this is done, the secondary IP address is active."
"DESCRIPTION 4"="To remove the secondary IP address again, simply click on the Remove button."
"DESCRIPTION 5"="The "Show GUID" can be used to retrieve the Interface GUID for the selected network connection."
"DESCRIPTION 6"="Please note that this listing will show you only those network connections that have DHCP activated. All non-DHCP enabled network connections will not be listed here. "
"AUTHOR"="Xteq Systems"
"CONTACTURL"="http://www.xteq.com/"
"COPYRIGHT"="Copyright  Xteq Systems - All Rights Reserved"
"COMMENT 1"="Thanks to Pierre Szwarc <pierre@xteq.com> for the idea!"
"COMMENT 2"="Found by Daniel Petri, http://www.petri.co.il/configure_tcp_ip_to_use_dhcp_and_a_static_ip_address_at_the_same_time.htm"


iCount=0

sP1="HKLM\SYSTEM\CurrentControlSet\Control\Network\{4D36E972-E325-11CE-BFC1-08002BE10318}\"
sV_ConName="\Connection\Name"

sV_TCP="HKLM\SYSTEM\CurrentControlSet\Services\Tcpip\Parameters\Interfaces\"
sV_DHCP="\EnableDHCP"
sV_IP="\IPAddress"
sV_Subnet="\SubnetMask"

Sub Plugin_Initialize 
 Call InitListbox
End Sub


Sub Plugin_Apply(ElementIndex,ElementSubIndex)
 if ElementSubIndex=0 then
    Call MsgError("Please select an entry first")
 else
    sInterfaceGUID=RegEnumElement(ElementSubIndex)

    if ElementIndex=1 then 'SHOW GUID
       Call MsgInformation("The GUID for the interface of the selected network connection is: " & sInterfaceGUID & chr(13) & chr(10) & "To copy this text to your clipboard: Press CTRL+C")
     end if

    if ElementIndex=2 then 'ADD/EDIT GUID
       sIP=GetSecondIPAdress(sInterfaceGUID)
       sSub=GetSecondSubnet(sInterfaceGUID)

       sINP_IP=InputWindow("Please enter the secondary IP number for this network connection, for example 192.168.85.13",sIP,1)

       if IsEmpty(sINP_IP)=false then
          if Len(sINP_IP)>0 then

             sINP_Sub=InputWindow("Please enter the secondary subnet mask for this network connection, for example 255.255.254.0",sSub,1)                  
             if IsEmpty(sINP_Sub)=false then
                if Len(sINP_Sub)>0 then

                   Call SetSecondIPAdress(sInterfaceGUID,sINP_IP)
                   Call SetSecondSubnet(sInterfaceGUID,sINP_Sub)
                   Call InitListbox()              


                end if
             end if
          end if
       end if
    end if

    if ElementIndex=3 then 'REMOVE
       Call SetSecondIPAdress(sInterfaceGUID,"")
       Call SetSecondSubnet(sInterfaceGUID,"")

       Call MsgInformation("The secondary IP has been removed.")
       Call InitListbox()              
    end if

    
 end if



End Sub


Sub InitListbox
 for i=1 to iCount
     Call SetUIElement(i,"")
 next

 iCount=0
 iTmp=RegEnumPaths(sP1)
 for i=1 to iTmp
     s=RegEnumElement(i)
     if left(s,1)="{" then
        sRegPath=sP1 & s & sV_ConName
        sName=RegReadValue(sRegPath)

        if InterfaceIsDHCP(s)=true then
           iCount=iCount+1

           sIP=GetSecondIPAdress(s)
           if len(sIP)=0 then 
              sIP="NONE"
           end if

           sSub=GetSecondSubnet(s)
           if len(sSub)=0 then 
              sSub="NONE"
           end if
              

               
           Call SetUIElement(i,sName & " - (" & sIP & "/" & sSub & ")")' & s)
        end if
     end if
 next
end sub

Function InterfaceIsDHCP(InterfaceName)
 r=false

 sReg=sV_TCP & InterfaceName & sV_DHCP
 i=RegReadValue(sReg)
 if i=1 then
    r=true
 else
    r=false
 end if

 InterfaceIsDHCP=r
End Function

Function GetSecondIPAdress(InterfaceName)
 sReg=sV_TCP & InterfaceName & sV_IP

 GetSecondIPAdress=GetSecondSomething(sReg)
End Function

Function GetSecondSubnet(InterfaceName)
 sReg=sV_TCP & InterfaceName & sV_Subnet

 GetSecondSubnet=GetSecondSomething(sReg)
End Function



Function GetSecondSomething(RegPath)
 r=""
 sReg=RegPath
 If RegValueExists(sReg) then
    ary=RegReadValue(sReg)
    if ubound(ary)>0 then
       'has second IP
       r=ary(1)
    else
       'no, not at this time
       r=""
    end if
 end if

 GetSecondSomething=r
End Function



Sub SetSecondIPAdress(InterfaceName,IPAddr)
 sReg=sV_TCP & InterfaceName & sV_IP

 Call SetSecondSomething(sReg,IPAddr)
End SUb

Sub SetSecondSubnet(InterfaceName,SubNet)
 sReg=sV_TCP & InterfaceName & sV_Subnet

 Call SetSecondSomething(sReg,SubNet)
End SUb


Sub SetSecondSomething(RegPath,RegData)
 Dim aryTwo()
 Redim aryTwo(1)

 sReg=RegPath
 ary=RegReadValue(sReg)

 if len(RegData)>0 then
    aryTwo(1)=RegData
 else
    Redim aryTwo(0)
 end if

 aryTwo(0)=ary(0)    
 Call RegWriteValue(sReg,aryTwo,5)
End SUb



Sub Plugin_Terminate 
End Sub



