"FILE"="Xteq Systems X-Setup Plugin 6.0"
"TYPE"="7"
"COUNT"="2"
"UIPATH"="Network\TCP/IP Hardening
"NAME"="MTU Detection"
"OSVERSION"="0001011"
"VERSION"="1.01"
"LANGUAGE"="VBScript"
"WARNING"="1"
"TEXT 1"="Enable automatic MTU detection (Default)"
"TEXT 2"="Do not try to detect the current MTU" 
"DESCRIPTION 1"="Inside a network, there is always a "data window" called Maximum Transmisson Unit (MTU) that defines how many data somebody can sent before an acknowledge needs to be sent."
"DESCRIPTION 2"="For example, in a default Ethernet network the MTU is 567 bytes. An example: a Client wants to sent some data to a server. The client first checks how big the current MTU is and splits the data (if needed) into chunks of 567 bytes. It then sends out the first chunk of 567 bytes and waits until the server send back a "OKAY, I received the 567 bytes correctly" message before the next chunk is sent. "
"DESCRIPTION 3"="567 bytes are good for most networks, but there might be cases where you need a bigger, or a smaller MTU. For example, if two server are connected with 1 GBit to each other, you can properly extend the MTU so they can sent more data in one step and speeding up the connection (less "OKAY, got that" messages). For this reason, Windows tries to automatically detect which MTU size it should be using." 
"DESCRIPTION 4"="Normally, there is absolutely no need to change this value but if you server is connected to the internet, some back hacks could trick Windows in such way that it thinks it should use a MTU of 1 byte. This means your server will send one byte of an HTML page and wait until the client says "OKAY, got that". Then it will send the next byte etc. This will of course result in a really bad performance of your server since it waits for OKAY messages most of the time."
"DESCRIPTION 5"="If this automatic detection is turned off, a hacker can not trick the server. "
"AUTHOR"="Xteq Systems"
"CONTACTURL"="http://www.xteq.com/"
"COPYRIGHT"="Copyright  Xteq Systems - All Rights Reserved"
"COMMENT 1"=" "



sP="HKLM\System\CurrentControlSet\Services\TcpIp\Parameters\EnablePMTUDiscovery" 'DW 0 = do not detect

Sub Plugin_Initialize 
 i=RegReadValue(sP)

 if i=1 or IsEmpty(i) then 
    SetUIElement 1,true
 else
    SetUIElement 2,true
 end if
 
End Sub

Sub Plugin_Apply(ElementIndex,ElementSubIndex)
 if GetUIElement(1)=true then
    If RegValueExists(sP) then 
       Call RegDeleteValue(sP)
    end if
 else
    Call RegWriteValue(sP,0,2)
 end if

 Call Restart()
End Sub

Sub Plugin_Terminate 
End Sub

